#[repr(transparent)]pub struct DcfgCcSocuDflt(pub u32);Expand description
With TZ-M, the part can be sold by level 1 customers (secure code developer) to level-2 customers who develops non-secure code only. - In this scenario, or easy of development, Level-I customer releases the part to always allow non-secure debug. - To allow level-2 customers to further seal the part DCFG_CC_SOCU_NS is used. - ROM will use this word to further restrict the debug access.
Tuple Fields
0: u32Implementations
Sourceimpl DcfgCcSocuDflt
impl DcfgCcSocuDflt
Sourcepub const fn set_spniden(&mut self, val: bool)
pub const fn set_spniden(&mut self, val: bool)
Secure non-invasive debug fixed state
Sourcepub const fn set_spiden(&mut self, val: bool)
pub const fn set_spiden(&mut self, val: bool)
Secure invasive debug fixed state
Sourcepub const fn isp_cmd_en(&self) -> bool
pub const fn isp_cmd_en(&self) -> bool
ISP Boot Command fixed state
Sourcepub const fn set_isp_cmd_en(&mut self, val: bool)
pub const fn set_isp_cmd_en(&mut self, val: bool)
ISP Boot Command fixed state
Sourcepub const fn fa_me_cmd_en(&self) -> bool
pub const fn fa_me_cmd_en(&self) -> bool
FA Command fixed state
Sourcepub const fn set_fa_me_cmd_en(&mut self, val: bool)
pub const fn set_fa_me_cmd_en(&mut self, val: bool)
FA Command fixed state
Sourcepub const fn inverse_value(&self) -> u16
pub const fn inverse_value(&self) -> u16
inverse value of bits [15:0]
Sourcepub const fn set_inverse_value(&mut self, val: u16)
pub const fn set_inverse_value(&mut self, val: u16)
inverse value of bits [15:0]